@@ -10,9 +10,7 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Classes to modify TrainingInput code to be compatible
-with version 2.0 and later of the SageMaker Python SDK.
-"""
+"""Classes to modify TrainingInput code to be compatible with version 2.0 and later."""
 from __future__ import absolute_import
 
 import ast
