@@ -1,4 +1,4 @@
-# Copyright 2017-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,9 +10,13 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Contains content types strings"""
+"""Deprecated content type constants. Just use the mime type strings."""
 from __future__ import absolute_import
 
+import deprecations
+
+deprecations.removed_warning("The sagemaker.content_types module")
+
 CONTENT_TYPE_JSON = "application/json"
 CONTENT_TYPE_CSV = "text/csv"
 CONTENT_TYPE_OCTET_STREAM = "application/octet-stream"
